@@ -409,10 +409,10 @@ def almanac(first_day, pagenum, dfra):
     \HRule \\[0.6cm]
     \end{center}
     \begin{description}\footnotesize
-    \item[Disclaimer:] These are computer generated tables. Use on your own risk. 
-    The accuracy has been checked as good as possible but can not be guaranteed. 
-    This means, if you get lost on the oceans because of errors in this publication I can not be held liable. 
-    For security relevant applications you should buy an official version of the nautical almanac.
+    \item[Disclaimer:] These are computer generated tables - use them at your own risk.
+    The accuracy has been randomly checked with JPL HORIZONS System, but cannot be guaranteed.
+    This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
+    Besides, this publication only contains the 'daily pages' of the Nautical Almanac: an official version of the Nautical Almanac is indispensable.
     \end{description}
 \end{titlepage}
 '''
