@@ -273,7 +273,7 @@ def starstab(date):
 
     # returns 3 tables with SHA & Mer.pass for Venus, Mars, Jupiter and Saturn
     for i in range(3):
-        datestr = r'''{} {} {}'''.format(date.strftime("%b"), (date+datetime.timedelta(days=i)).strftime("%d"), (date+datetime.timedelta(days=i)).strftime("%a"))
+        datestr = r'''{} {} {}'''.format((date+datetime.timedelta(days=i)).strftime("%b"), (date+datetime.timedelta(days=i)).strftime("%d"), (date+datetime.timedelta(days=i)).strftime("%a"))
         m = m + '''\hline
 '''
         if config.tbls == "m":
@@ -1133,10 +1133,10 @@ def almanac(first_day, pagenum, df180, df360, dfcm):
     \HRule \\[0.2cm]
     \end{center}
     \begin{description}\footnotesize
-    \item[Disclaimer:] These are computer generated tables. Use on your own risk. 
-    The accuracy has been checked as good as possible but can not be guaranteed. 
-    This means, if you get lost on the oceans because of errors in this publication I can not be held liable. 
-    For security relevant applications you should buy an official version of the nautical almanac. You need one anyway since this publication only contains the daily pages of the Nautical Almanac.
+    \item[Disclaimer:] These are computer generated tables - use them at your own risk.
+    The accuracy has been randomly checked with JPL HORIZONS System, but cannot be guaranteed.
+    This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
+    Besides, this publication only contains the 'daily pages' of the Nautical Almanac: an official version of the Nautical Almanac is indispensable.
     \end{description}
 \end{titlepage}
 \restoregeometry    % so it does not affect the rest of the pages'''
